Coverage for pygeodesy/deprecated/rhumbx.py: 100%

1

2# -*- coding: utf-8 -*-

3

4 u'''DEPRECATED on 2023.11.26, use module L{pygeodesy.rhumb.ekx} instead.

5'''

6

7 from pygeodesy.rhumb.ekx import * # noqa: F403

8 from pygeodesy.lazily import _ALL_LAZY

9

10 __all__ = _ALL_LAZY.rhumb_ekx # attrs NOT DEPRECATED

11 __version__ = '25.05.12'

12

13# **) MIT License

14#

15# Copyright (C) 2016-2026 -- mrJean1 at Gmail -- All Rights Reserved.

16#

17# Permission is hereby granted, free of charge, to any person obtaining a

18# copy of this software and associated documentation files (the "Software"),

19# to deal in the Software without restriction, including without limitation

20# the rights to use, copy, modify, merge, publish, distribute, sublicense,

21# and/or sell copies of the Software, and to permit persons to whom the

22# Software is furnished to do so, subject to the following conditions:

23#

24# The above copyright notice and this permission notice shall be included

25# in all copies or substantial portions of the Software.

26#

27# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS

28# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,

29# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL

30# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR

31# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,

32# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR

33# OTHER DEALINGS IN THE SOFTWARE.